clear
close all
clc

%% get the path to the file and loads it
col = linspecer(3); %defines colors for plots

T = loadVstep('Vstep191030_10_572.dat','D:\Luca\Analysis\Data\PCB amp test\PCB Vstep\');

%% Rise and fall time calculation

[tsettleI,tsettleV] = computeSettling(T,5);
% SV = stepinfo(T.V(T.t>=1),T.t(T.t>=1),mean(T.V(end-500,end)));
% SI = stepinfo(T.I(T.t>=1),T.t(T.t>=1),mean(T.I(end-500,end)));
% 
% triseV = SV.RiseTime;
% triseI = SI.RiseTime;


%% Fitting

minfit = 1.0; %minimum time to be considered in the fit
maxfit = 1.06; %maximum time to be considered in the fit

% X = [T.t T.V];
% 
% fun = @(lim) 1 - VstepFitR2([minfit lim],X);
% maxfit = fminbnd(fun,1,1.5);


%offset the curve by the end value (i.e. the stabilized voltage/current)
offsetV = mean(T.V(end-500:end));
offsetI = mean(T.I(end-500:end));

%selects the limited part of the measuremnt
tfit = T.t(T.t>=minfit &T.t<=maxfit);
tmpI = T.I(T.t>=minfit &T.t<=maxfit)-offsetI;
tmpV = T.V(T.t>=minfit &T.t<=maxfit)-offsetV;
Vfit = log(abs(tmpV));
Ifit = log(abs(tmpI));

tmpfitV = fit(tfit,Vfit,'poly1');
tmpfitI = fit(tfit,Ifit,'poly1');

Vplot = sign(tmpV).*exp(tmpfitV(tfit))+offsetV;
tauV = -1/tmpfitV.p1;
Iplot = sign(tmpI).*exp(tmpfitI(tfit))+offsetI;
tauI = -1/tmpfitI.p1;

figure
hold on
plot(tfit,Vfit)
plot(tfit,tmpfitV(tfit))
xlabel('time (s)')
ylabel('ln(V)')

figure
hold on
plot(tfit,Ifit)
plot(tfit,tmpfitI(tfit))
xlabel('time (s)')
ylabel('ln(I)')

%% plots Vout

figure('Position',[100 100 800 600])
hold on
plot(T.t,T.V,'linewidth',2)
plot(tfit,Vplot,'linewidth',2)
xlim([0.9 1.2])
xlabel('time (s)')
ylabel('Vout (V)')
set(gca,'fontsize',20,'fontweight','normal')
set(findall(gcf,'type','text'),'fontsize',20,'fontweight','normal')
set(gca,'linewidth',1.5,'box','on')
set(gcf,'color','white')
set(gca,'TickLength',[0.02, 0.002])

%% plots I

figure('Position',[100 100 800 600])
hold on
plot(T.t,T.I,'linewidth',2)
plot(tfit,Iplot,'linewidth',2)

xlim([0.9 1.2])
xlabel('time (s)')
ylabel('Current (I)')
set(gca,'fontsize',20,'fontweight','normal')
set(findall(gcf,'type','text'),'fontsize',20,'fontweight','normal')
set(gca,'linewidth',1.5,'box','on')
set(gcf,'color','white')
set(gca,'TickLength',[0.02, 0.002])