function [tsettleI,tsettleV] = computeSettling(T,error,points,tswitch)
%Computes settling time of a step signal where the change happes at T.t =
%tswitch s, and that is considered stabilized when it is within error % of the
%final value. Points is the number of points to average to find the stable
%initial and final value of the output.
if nargin < 4
    tswitch = 1;
    if nargin<3
        points = 500;
    end
end


idx = (T.t > 0.8); %crops out any artifact due to initial voltage ramp
x = T.t(idx);
y = (T.I(idx)); %restricts the current vector
lim1 = (1 + error/100) * mean(y(end-points:end)); %finds the value correspondig to 100%+error of the final current
lim2 = (1 - error/100) * mean(y(end-points:end)); %finds the value correspondig to 100%-error of the final current
[~,idx1] = min(abs(y - lim1));
[~,idx2] = min(abs(y - lim2));

tsettleI = x(min([idx1,idx2]))-tswitch;


y2 =  (T.V(idx)); %restricts the voltage vector

voltrange = abs(mean(y2(1:500)) - mean(y2(end-points:end))); % computes the total voltage jump that is measured
lim1 = mean(y2(end-points:end))+voltrange*error/100; %finds the value correspondig to 100%+error of the final voltage
lim2 = mean(y2(end-points:end))-voltrange*error/100; %finds the value correspondig to 100%+error of the final voltage
[~,idx1] = min(abs(y2 - lim1));
[~,idx2] = min(abs(y2 - lim2));

tsettleV = x(min([idx1,idx2]))-tswitch;

% %%
% figure
% hold on
% plot(T.t,T.I)
% scatter(x(idx1),y(idx1))
% scatter(x(idx2),y(idx2))
% xlim([0.9995 1.0005])
% %%
% figure
% hold on
% plot(x,y)
% xlim([0.9995 1.0005])
% 
% %%
% 
% 
% Verror = T.V(idx1)- mean(y2(end-500:end));
% 
% %%
% figure
% hold on
% plot(T.t,T.V)
% scatter(x(idx1),y2(idx1))
% scatter(x(idx2),y2(idx2))
% xlim([0.9995 1.0005])
end


