%% Plots example of the amplifier calibration
clear
close all
clc

%% Loads the IVs for differen resistor, the colums in each table are applied bias, estimated current (with previous calibration), and measured voltage bin
T{1} = readtable('D:\Luca\Analysis\Data\PCB amp test\calibration\new logamp september 2019 3\Data\10.dat'); %10 Ohms
T{2} = readtable('D:\Luca\Analysis\Data\PCB amp test\calibration\new logamp september 2019 3\Data\100.dat'); %100 Ohms
T{3} = readtable('D:\Luca\Analysis\Data\PCB amp test\calibration\new logamp september 2019 3\Data\1000.dat'); %1 kOhms
T{4} = readtable('D:\Luca\Analysis\Data\PCB amp test\calibration\new logamp september 2019 3\Data\10000.dat'); %10 kOhms
T{5} = readtable('D:\Luca\Analysis\Data\PCB amp test\calibration\new logamp september 2019 3\Data\100000.dat'); %100 kOhms
T{6} = readtable('D:\Luca\Analysis\Data\PCB amp test\calibration\new logamp september 2019 3\Data\1000000.dat'); %1 MOhms
T{7} = readtable('D:\Luca\Analysis\Data\PCB amp test\calibration\new logamp september 2019 3\Data\10000000.dat'); %10 MOhms
T{8} = readtable('D:\Luca\Analysis\Data\PCB amp test\calibration\new logamp september 2019 3\Data\100000000.dat'); %100 MOhms
T{9} = readtable('D:\Luca\Analysis\Data\PCB amp test\calibration\new logamp september 2019 3\Data\1000000000.dat'); %1 GOhms
T{10} = readtable('D:\Luca\Analysis\Data\PCB amp test\calibration\new logamp september 2019 3\Data\10000000000.dat'); %10 GOhms

final = readtable('D:\Luca\Analysis\Data\PCB amp test\calibration\new logamp september 2019 3\Data\PCB_test_2_18bit.txt'); %final curve 

col  = linspecer(length(T)); %defines color space
%s = {'o', '+', '*', 'x','s','d','^','v','p','h'}; %list of symbols to use
s = {'o', 'o', 'o', 'o','o','o','o','o','o','o'}; %list of symbols to use
R = [10 100 1e3 1e4 1e5 1e6 1e7 1e8 1e9 1e10] ; %values of resistance corresponding to each file

savepath = 'D:\Luca\SURFdrive\Dissertation\Chap 2\amplifier\';
name = 'calibration';
%%

for i = 1:length(T)
    T{i}.Var3 = T{i}.Var3 * (2*2.5/2^18) - 2.5; %converts bin value to voltage
end

final.Var1 = final.Var1 * (2*2.5/2^18) - 2.5; %converts bin value to voltage

% finds points in 10 100 1000 Ohms measurements at 0.1V; due to the voltage
% divider, the value that is compared is 0.2V
[~,idx1p] = min(abs(T{1}.Var1-0.2));
[~,idx1n] = min(abs(T{1}.Var1+0.2));
[~,idx2p] = min(abs(T{2}.Var1-0.2));
[~,idx2n] = min(abs(T{2}.Var1+0.2));
[~,idx3p] = min(abs(T{3}.Var1-0.2));
[~,idx3n] = min(abs(T{3}.Var1+0.2));


%% Complete plot
F = figure('Position',[50 50 600 800]);
hold on
for i = 1:length(T)
    x= T{i}.Var3(abs(T{i}.Var1)>5e-3); %measured output voltage, with exclusion of points measured at <3mV bias
    y= 0.5*T{i}.Var1(abs(T{i}.Var1)>5e-3) ./ R(i); %expected current value, calculated as applied bias / resistance; points at bias < 3mV are excluded; The 0.5* vactor is to account for the voltage divider in the PCB
    scatter(x,abs(y),s{i},'markeredgecolor',col(i,:))
end

scatter(T{1}.Var3(idx1p),0.5*abs(T{1}.Var1(idx1p)./R(1)),100,'rs','filled')
scatter(T{1}.Var3(idx1n),0.5*abs(T{1}.Var1(idx1n)./R(1)),100,'rs','filled')
scatter(T{2}.Var3(idx2p),0.5*abs(T{2}.Var1(idx1p)./R(2)),100,'rs','filled')
scatter(T{2}.Var3(idx2n),0.5*abs(T{2}.Var1(idx1n)./R(2)),100,'rs','filled')
scatter(T{3}.Var3(idx3p),0.5*abs(T{3}.Var1(idx1p)./R(3)),100,'rs','filled')
scatter(T{3}.Var3(idx3n),0.5*abs(T{3}.Var1(idx1n)./R(3)),100,'rs','filled')
plot(final.Var1,abs(final.Var3),'--k','linewidth',1)
set(gca,'yscale','log')

set(gca,'fontsize',20,'fontweight','normal')
set(findall(gcf,'type','text'),'fontsize',20,'fontweight','normal')
set(gca,'linewidth',1.5,'box','on')
set(gcf,'color','white')
set(gca,'TickLength',[0.02, 0.002])
set(gca,'YTick', [1e-15 1e-14 1e-13 1e-12 1e-11 1e-10 1e-9 1e-8 1e-7 1e-6 1e-5 1e-4 1e-3 1e-2 1e-1 1 1e1 1e2]);
%set(gca,'YMinorTick', 'off');

xlabel('Output Voltage (V)')
ylabel('Current (A)')
legend({'10','100','1k','10k','100k','1M','10M','100M','1G','10G'})

%SaveFigure(F,savepath,name)
%saveas(F,[savepath name '.eps'],'epsc')
%exportgraphics(gcf,[savepath name '.eps'],'BackgroundColor','none','ContentType','vector')

%% only data
F2 = figure('Position',[50 50 600 800]);
hold on
for i = 1:length(T)
    x= T{i}.Var3(abs(T{i}.Var1)>5e-3); %measured output voltage, with exclusion of points measured at <3mV bias
    y= 0.5*T{i}.Var1(abs(T{i}.Var1)>5e-3) ./ R(i); %expected current value, calculated as applied bias / resistance; points at bias < 3mV are excluded; The 0.5* vactor is to account for the voltage divider in the PCB
    scatter(x,abs(y),s{i},'markeredgecolor',col(i,:))
end

set(gca,'yscale','log')

set(gca,'fontsize',20,'fontweight','normal')
set(findall(gcf,'type','text'),'fontsize',20,'fontweight','normal')
set(gca,'linewidth',1.5,'box','on')
set(gcf,'color','white')
set(gca,'TickLength',[0.02, 0.002])
set(gca,'YTick', [1e-15 1e-14 1e-13 1e-12 1e-11 1e-10 1e-9 1e-8 1e-7 1e-6 1e-5 1e-4 1e-3 1e-2 1e-1 1 1e1 1e2]);
%set(gca,'YMinorTick', 'off');

xlabel('Output Voltage (V)')
ylabel('Current (A)')
legend({'10','100','1k','10k','100k','1M','10M','100M','1G','10G'})

SaveFigure(F2,savepath,[name '_onlydata'])
saveas(F2,[savepath [name '_onlydata'] '.eps'],'epsc')

%% Only fit
F3 = figure('Position',[50 50 600 800]);
hold on

scatter(T{1}.Var3(idx1p),0.5*abs(T{1}.Var1(idx1p)./R(1)),100,'rs','filled')
scatter(T{1}.Var3(idx1n),0.5*abs(T{1}.Var1(idx1n)./R(1)),100,'rs','filled')
scatter(T{2}.Var3(idx2p),0.5*abs(T{2}.Var1(idx1p)./R(2)),100,'rs','filled')
scatter(T{2}.Var3(idx2n),0.5*abs(T{2}.Var1(idx1n)./R(2)),100,'rs','filled')
scatter(T{3}.Var3(idx3p),0.5*abs(T{3}.Var1(idx1p)./R(3)),100,'rs','filled')
scatter(T{3}.Var3(idx3n),0.5*abs(T{3}.Var1(idx1n)./R(3)),100,'rs','filled')
plot(final.Var1,abs(final.Var3),'--k','linewidth',1)
set(gca,'yscale','log')

set(gca,'fontsize',20,'fontweight','normal')
set(findall(gcf,'type','text'),'fontsize',20,'fontweight','normal')
set(gca,'linewidth',1.5,'box','on')
set(gcf,'color','white')
set(gca,'TickLength',[0.02, 0.002])
set(gca,'YTick', [1e-15 1e-14 1e-13 1e-12 1e-11 1e-10 1e-9 1e-8 1e-7 1e-6 1e-5 1e-4 1e-3 1e-2 1e-1 1 1e1 1e2]);
%set(gca,'YMinorTick', 'off');

xlabel('Output Voltage (V)')
ylabel('Current (A)')
legend({'10','100','1k','10k','100k','1M','10M','100M','1G','10G'})

SaveFigure(F3,savepath,[name '_onlyfit'])
saveas(F3,[savepath [name '_onlyfit'] '.eps'],'epsc')

%% Fit linear range

% idx = final.Var1 >-2 & final.Var1<-1;
% 
% x = final.Var1(idx);
% y = log10(abs(final.Var2(idx)));
