%% Script to plot two traces with different breaking speeds
clear
close all
clc

savepath = 'D:\Luca\SURFdrive\Dissertation\Chap 2\amplifier\';
name = 'trace_break_speed_comp';
file30 = 'D:\Luca\Analysis\Data\PCB amp test\Sample 4\Gold\5\scan200302_44\scan200302_44.mat'; %path to the file of the 30V/s measurement as saved by Plot_Raw.m
file50 = 'D:\Luca\Analysis\Data\PCB amp test\Sample 4\Gold\5\scan200302_43\scan200302_43.mat'; %path to the file of the 50V/s measurement as saved by Plot_Raw.m
file200 = 'D:\Luca\Analysis\Data\PCB amp test\Sample 4\Gold\5\scan200302_42\scan200302_42.mat';%path to the file of the 200V/s measurement as saved by Plot_Raw.m

col = linspecer(5);

%% Select a single example trace from each measurement

tmp = load(file30);
trace_30 = tmp.G(2); %2 15 18
clear tmp
close all
clc

tmp = load(file50);
trace_50 = tmp.G(10); %3 32
clear tmp
close all
clc

tmp = load(file200);
trace_200 = tmp.G(10); %3 7 20
clear tmp
close all
clc

%% Plots the overlayed traces
F = figure('Position',[50 50 600 800]);
hold on
%plots traces
plot(trace_30.d_breaking,trace_30.g_breaking,'color',col(1,:),'linewidth',2)
plot(trace_50.d_breaking,trace_50.g_breaking,'color',col(2,:),'linewidth',2)
plot(trace_200.d_breaking,trace_200.g_breaking,'color',col(3,:),'linewidth',2)

%plots lines as eyeguide
plot(linspace(-1,3,100),2e-4.*ones(100,1),'color','black','linestyle','--','linewidth',2)
plot(linspace(-1,3,100),2e-6.*ones(100,1),'color','black','linestyle','--','linewidth',2)
plot(linspace(-1,3,100),2e-8.*ones(100,1),'color','black','linestyle','--','linewidth',2)
% patch([-1 3 3 -1],[2e-6 2e-6 2e-4 2e-4],col(4,:),'facealpha',0.07,'edgecolor','none')
% patch([-1 3 3 -1],[2e-8 2e-8 2e-6 2e-6],col(4,:),'facealpha',0.15,'edgecolor','none')


set(gca,'yscale','log')
xlim([-0.5 2.5])
ylim([2e-9 3])
xlabel('Electrode displacement (nm)')
ylabel('Conductance (G_0)')
set(gca,'fontsize',20,'fontweight','normal')
set(findall(gcf,'type','text'),'fontsize',20,'fontweight','normal')
set(gca,'linewidth',1.5,'box','on')
set(gcf,'color','white')
set(gca,'TickLength',[0.02, 0.002])
legend({'30 V s^{-1}','50 V s^{-1}','200 V s^{-1}'})
set(gca,'YTick', [1e-8 1e-7 1e-6 1e-5 1e-4 1e-3 1e-2 1e-1 1 1e1 1e2]);

SaveFigure(F,savepath,name)
saveas(F,[savepath name '.eps'],'epsc')
